@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2014 by The BRLTTY Developers.
+ * Copyright (C) 1995-2016 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2 of the License, or (at your option) any
  * later version. Please see the file LICENSE-GPL for details.
  *
- * Web Page: http://mielke.cc/brltty/
+ * Web Page: http://brltty.com/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -25,8 +25,8 @@
 extern "C" {
 #endif /* __cplusplus */
 
-extern int tellSpeechFinished (void);
-extern int tellSpeechLocation (int index);
+extern int tellSpeechFinished (volatile SpeechSynthesizer *spk);
+extern int tellSpeechLocation (volatile SpeechSynthesizer *spk, int index);
 
 extern unsigned int getIntegerSpeechVolume (unsigned char setting, unsigned int normal);
 extern unsigned int getIntegerSpeechRate (unsigned char setting, unsigned int normal);
